/* 
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *         (C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include <string.h>
#include <unistd.h>
#include <signal.h>
#include <stdio.h>
#include <sys/types.h>
#include <sys/wait.h>

/*
 * This little program creates a new process group and
 * forks to start the given program.
 * 
 * The option -o specifies that the program should write it's
 * exit code followed by a '#' into the following file, e.g.:
 * 
 * pgrpmgr -o 255 sh -c 'exit 255'
 * 
 * (The file contains "255#" afterwards)
 * 
 * When it receives SIGTERM, it forwards it to the whole
 * process group and terminates itself with the same exit
 * code as the children it forked.
 * 
 * This program doesn't work if the invocated program
 * creates it's own process group, like sh(1).
 */

static pid_t child;

void sighdl(int sig) {
   signal(sig, SIG_IGN);
   killpg(0, sig);
}

int main(__unused int argc, char *argv[]) {
	int status;
	char *exitFile = NULL, **arg0;
	FILE *f;

	if(argc == 1)
		return 1;
		
	if(strcmp(argv[1], "-o") == 0) {
		/* -o specified */
		exitFile = argv[2];
		arg0 = &argv[3];
	} else
		arg0 = &argv[1];

	setsid();

   child = fork();
   if(child == 0)
      /* Child (return is only executed if execvp failed) */
      return (execvp(*arg0, arg0) < 0);
   else
		/* Parent registers itself as signal handler */
      signal(SIGTERM, sighdl);

   do {
     wait(&status);
   } while(!WIFSIGNALED(status) && !WIFEXITED(status));
   
   status = WEXITSTATUS(status);
   
   if(exitFile != NULL) {
   	f = fopen(exitFile, "w");
   	fprintf(f, "%i#", status);
   	fclose(f);
   }

   return status;
}
