/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *			(C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include <qtimer.h>
#include <qprocess.h>
#include <qeventloop.h>
#include <qapplication.h>
#include <qprogressdialog.h>

#include <dbsdglobal.h>
#include <dialogs.h>
#include <frmactionlist.h>
#include <fastestcvsupengine.h>
#include <unixprocess.h>
#include <pkgupgradeengine.h>

/* ATTENTION
 *	The IDs in bgrpPkgUse must correspond to PkgUpgradeEngine::PackageUse!
 */

void frmPkgSettings::fastestCVSUp() {
	editCVSUpServer->setText("");

	fcprocess = FastestCVSUpEngine::getProcess();
	if(fcprocess != NULL) {
		connect(fcprocess, SIGNAL(processExited()), SLOT(fastestCVSUpExited()));
	
		if(fcprocess->start()) {
			fcpdlg = new QProgressDialog(this, NULL, true);
			disconnect(fcpdlg, SIGNAL(canceled()), fcpdlg, SLOT(cancel()));
			connect(fcpdlg, SIGNAL(canceled()), SLOT(fastestCVSUpCanceled()));
			fcpdlg->setCaption("DesktopBSD");
			fcpdlg->setTotalSteps(0); /* busy indicator */
			
			fastestCVSUpProgress();
		} else
			Dialogs::warnDlg(tr("Error: fastest_cvsup couldn't be started."));
	}
}

void frmPkgSettings::accept() {
	settings.writeEntry("package_use", bgrpPkgUse->selectedId());
	settings.writeEntry("recursive", chkRecursive->isChecked());
	settings.writeEntry("upward_recursive", chkUpwardRecursive->isChecked());
	settings.writeEntry("keep_going", chkKeepGoing->isChecked());
	settings.writeEntry("make_args", QStringList::split(' ', editMakeArgs->text()));
	settings.writeEntry("make_env", QStringList::split(' ', editMakeEnv->text()));
	settings.writeEntry("cvsup_server", editCVSUpServer->text());
	settings.writeEntry("package_directory", editPackageDir->text());

	QDialog::accept();
}


void frmPkgSettings::init() {
	settings.beginGroup("/packages");

	bgrpPkgUse->setButton(settings.readNumEntry("package_use"));
	chkRecursive->setChecked(settings.readBoolEntry("recursive"));
	chkUpwardRecursive->setChecked(settings.readBoolEntry("upward_recursive"));
	chkKeepGoing->setChecked(settings.readBoolEntry("keep_going"));
	editMakeArgs->setText(settings.readListEntry("make_args").join(" "));
	editMakeEnv->setText(settings.readListEntry("make_env").join(" "));
	editCVSUpServer->setText(settings.readEntry("cvsup_server"));
	editPackageDir->setText(settings.readEntry("package_directory"));
	lblDefaultPackageDir->setText(tr("Default: <i>%1</i>").arg(PkgUpgradeEngine::readDefaultRepository()));

	btnFastestCVSUp->setIconSet(DBSDGlobal::getIconLoader()->loadIcon("find", DBSDIconLoader::Button));
}


void frmPkgSettings::fastestCVSUpExited() {
	if(fcprocess->normalExit() && fcprocess->exitStatus() == 0)
		editCVSUpServer->setText(fcprocess->readLineStdout());
	
	delete fcprocess;
	fcprocess = NULL;
}


void frmPkgSettings::fastestCVSUpProgress() {
	if(fcprocess != NULL) {
		fcpdlg->setProgress(fcpdlg->progress() + 8);
		QTimer::singleShot(30, this, SLOT(fastestCVSUpProgress()));
	} else {
		delete fcpdlg;
		fcpdlg = NULL;
	}
}


void frmPkgSettings::fastestCVSUpCanceled() {
	if(fcprocess != NULL)
		fcprocess->tryTerminate();
}



void frmPkgSettings::openServerList(const QString & url) {
	UnixProcess process(QStringList::split(' ', "/usr/local/bin/kfmclient exec"));
	process.addArgument(url);

	if(!process.start())
		Dialogs::warnDlg(tr("Error: Cannot launch browser.\n"
								  "(kfmclient couldn't be started)"));
}


void frmPkgSettings::customMakeInfo() {
	if(bgrpPkgUse->selected() == radUsePackages && !editMakeArgs->text().isEmpty())
		Dialogs::infoDlg(tr("You have selected \"Binary packages whenever possible\" as installation\n"
								  "method, but since custom make arguments are specified, software will\n"
								  "be always built from source."));
}
