/* 
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *         (C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include "wndmain.h"

#include <err.h>

#include <dbsdglobal.h>
#include <dbsdkiconloader.h>
#include <translation.h>
#include <variables.h>

#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>

int main(int argc, char *argv[]) {
   /* Not root - run using kdesu */
   if(geteuid() != 0) {
      char *args[argc + 2];
      args[0] = "kdesu";

      int i;
      for(i = 0; i < argc; ++i)
        args[i + 1] = argv[i];
      
      args[i + 1] = NULL;
   
      execv("/usr/local/bin/kdesu", args);
      
      /* Shouldn't be reached */
      err(1, "Couldn't execute kdesu");
   }

	KAboutData  about("dbsd-pkgmgr", "DesktopBSD Package Manager",
							"", NULL, KAboutData::License_BSD);

	KCmdLineArgs::init(argc, argv, &about);
	KApplication::addCmdLineOptions();
	KApplication a;

	char *user = getenv("KDESU_USER");
	Variables::setValue("pkgmgr.user", ((user != NULL) ? user : "root"));

	DBSDGlobal::setIconLoader(new DBSDKIconLoader);
	Translation::installTranslator();
	
	wndMain w;
	w.initModule();
	w.show();
   
	a.connect(&a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()));
	return a.exec();
}
