/* 
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *         (C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include <qtimer.h>
#include <qpixmap.h>
#include <kpassivepopup.h>
#include <qtooltip.h>

#include <dbsdglobal.h>
#include <battery.h>
#include <batterytray.h>

/* Minimum/maximum value for update interval (in seconds) */
#define _UPDATE_MIN 5
#define _UPDATE_MAX 30

BatteryTray::BatteryTray() {
}

BatteryTray::~BatteryTray() {
}

void	BatteryTray::polish() {
	uint	updateTime = Battery::infoExpires();

	/* Check for bad values and replace
	 * them if necessary.
	 */
	if(updateTime < _UPDATE_MIN)
		updateTime = _UPDATE_MIN;
	else if(updateTime > _UPDATE_MAX)
		updateTime = _UPDATE_MAX;

	updateTime = 2;

	timer = new QTimer(this);
	connect(timer,  SIGNAL(timeout()),  SLOT(updateStatus()));
	timer->start(updateTime * 1000,  false);
}


void  BatteryTray::updateStatus() {
	DBSDIconLoader  *iloader = DBSDGlobal::getIconLoader();
	QImage  image;
	
	static bool lifeVeryLowShown = false,
					lifeLowShown = false;

	int  acline = Battery::powerSource();
	int  time = Battery::getTime();
	int  life = Battery::getLife();

	QString  tipText = tr("Power Source: %1\n", "The power source of a mobile device");

	if(acline == Battery::PS_ACLine) {
		tipText = tipText.arg(tr("AC Line"));

		if(life >= 0  &&  life  <= 100)
			image = DBSDGlobal::getIconLoader()->loadIcon("dbsd-battinfo-recharge",
																		 DBSDIconLoader::Size22x22).convertToImage();
		else
			setPixmap(iloader->loadIcon("dbsd-battinfo-power", DBSDIconLoader::Size22x22));

		lifeVeryLowShown = false;
		lifeLowShown = false;
	} else {
		tipText = tipText.arg(tr("Battery"));
		image = DBSDGlobal::getIconLoader()->loadIcon("dbsd-battinfo-battery",
																	 DBSDIconLoader::Size22x22).convertToImage();

		/** @todo Do not hardcode values */
		if(!lifeVeryLowShown)
			if(life <= 5) {
				KPassivePopup::message(tr("Low Battery"), tr("Battery status: %1%.").arg(life),
											  image, this);
				lifeVeryLowShown = true;
			} else if(!lifeLowShown  &&  life  <= 10) {
				KPassivePopup::message(tr("Low Battery"), tr("Battery status: %1%.").arg(life),
											  image, this);
				lifeLowShown = true;
			}
	}

	if(life >= 0 && life <= 100) {
		for(uint y = 0;  y < (float) (image.height() - 9) / 100 * (100 - life) + 4;  ++y)
			for(uint x = 0;  x < image.width();  ++x) {
				uint rgba = image.pixel(x, y);

				/* Don't change transparent pixels */
				if(qAlpha(rgba) < 190)
					continue;
			
				QColor c;
				int h, s ,v;
				c.setRgb(rgba);
				c.getHsv(&h, &s, &v);
				c.setHsv(h, 0, ((v *= 1.1) > 255) ? 255 : v);
				image.setPixel(x, y, c.rgb());
			}

		setPixmap(QPixmap(image));

		tipText += tr("Battery Status: %1 %\n").arg(life);
	}

	if(time > 0) {
		tipText += tr("Time left: ~ %1");

		int  minutes = time % 60,
		               hours = time / 60;

		if(hours == 0)
			tipText = tipText.arg(tr("%1 minutes")).arg(minutes);
		else {
			if(minutes >= 10)
				tipText = tipText.arg(tr("%1:%2 hours"));
			else
				tipText = tipText.arg(tr("%1:0%2 hours"));

			tipText = tipText.arg(hours).arg(minutes);
		}
	}

	QToolTip::remove(this);
	QToolTip::add(this,  tipText);
}
