/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *         (C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#ifndef __ACTIONLIST_H
#define __ACTIONLIST_H

#include <qlistview.h>

/** Class to show the user which actions
  * are currently performed.
  */
class ActionList : protected QListView {
	Q_OBJECT

public:
	ActionList(QWidget  *parent,  const char *name = NULL,  WFlags  flags = 0);

	int   addAction(QString  action,  int  parent = -1,  int  precedessor = -1);
	void  actionSuccessful();
	void  actionFailed();
	void  actionFailedStop();
	void  actionSuccessfulStop();
	void  processNextAction();
	int   currentIndex();

	int	getNumFailedActions();
	int	getNumSuccessfulActions();

public slots:
	void	show() { QListView::show(); }
	void	hide() { QListView::hide(); }

private:
	QListViewItem  *findLastItem(QListViewItem*);
	void  processAction(QListViewItem *);
	int   getIndex(QListViewItem *);
	QListViewItem  *findItem(int);

	QListViewItem   *currentAction;

	int  numFailedActions,
	     numSuccessfulActions;
};

#endif /* __ACTIONLIST_H */
