/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *			(C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include <dbsdglobal.h>
#include <dbsdiconloader.h>

void  frmActionList::init() {
	canceled = false;
	finished = false;

	DBSDIconLoader *iloader = DBSDGlobal::getIconLoader();
	btnCancel->setIconSet(iloader->loadIcon("button_cancel",
														 DBSDIconLoader::Button));
}


bool frmActionList::wasCanceled() {
	return  canceled;
}

/** exec() returns Rejected when the user
  * pressed cancel or Accepted when
  * all actions were done and the user
  * clicked 'Close'
  */
void frmActionList::close() {
	canceled = !finished;

	if(finished)
		accept();
	else
		reject();
}


ActionList * frmActionList::getActionList() {
	return  actionList;
}


/** Tells the dialog that all actions were
  * done and replaces 'Cancel' with 'Close'.
  */
void frmActionList::setFinished(bool  finished) {
	canceled = !finished;
	this->finished = finished;

	if(finished) {
		btnCancel->setText(tr("Close"));
		btnCancel->setIconSet(DBSDGlobal::getIconLoader()->loadIcon("button_ok",
																						DBSDIconLoader::Button));
	} else {
		btnCancel->setText(tr("Cancel"));
		btnCancel->setIconSet(DBSDGlobal::getIconLoader()->loadIcon("button_cancel",
																						DBSDIconLoader::Button));
	}
}


/** Enables/disables the "Cancel" or "Finish"
  * button.
  */
void frmActionList::setCancelFinishEnabled(bool b) {
	if(b)
		btnCancel->show();
	else
		btnCancel->hide();
}
