/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *			(C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include <dbsdglobal.h>
#include <dbsdiconloader.h>

void  frmTerminalActionList::init() {
	canceled = false;
	finished = false;

	initGraphics();
}


bool frmTerminalActionList::wasCanceled() {
	return  canceled;
}

/** exec() returns Rejected when the user
  * pressed cancel or Accepted when
  * all actions were done and the user
  * clicked 'Close'
  */
void frmTerminalActionList::cancelClicked() {
	canceled = !finished;

	if(finished)
		accept();
	else
		reject();
}


ActionList * frmTerminalActionList::getActionList() {
	return  actionList;
}


/** Tells the dialog that all actions were
  * done and replaces 'Cancel' with 'Close'.
  */
void frmTerminalActionList::setFinished(bool  finished) {
	canceled = !finished;
	this->finished = finished;

	if(finished) {
		btnCancel->setText(tr("Close"));
		btnCancel->setIconSet(DBSDGlobal::getIconLoader()->loadIcon("fileclose",
																						DBSDIconLoader::Button));
	} else {
		btnCancel->setText(tr("Cancel"));
		btnCancel->setIconSet(DBSDGlobal::getIconLoader()->loadIcon("button_cancel",
																						DBSDIconLoader::Button));
	}
}


TerminalDisplay * frmTerminalActionList::getTerminalDisplay() {
	return  terminalDisplay;
}


void frmTerminalActionList::initGraphics() {
	DBSDIconLoader *iloader = DBSDGlobal::getIconLoader();
	btnCancel->setIconSet(iloader->loadIcon("button_cancel", DBSDIconLoader::Button));
}
