/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *			(C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include <dbsdglobal.h>
#include <device.h>
#include <dialogs.h>

static  modDevInfo  *object = NULL;

void  setObject(modDevInfo  *obj) {
	object = obj;
}


int  wrapper(devinfo_dev *dev,  void *arg) {
	if(object != NULL)
		return  object->insertDevice(dev, arg);

	return -1;
}


int  modDevInfo::insertDevice(devinfo_dev  *dev,  void  *arg) {
	static  QListViewItem  *parents[32];

	if(dev->dd_name[0] != '\0' && dev->dd_state >= DIS_ATTACHED) {
		Device  device(dev->dd_name);
		uint level = (uint) arg;

		/* Check the index in parents[], even if it is
		 * highly unlikely that it is > 32.
		 */
		if(level < sizeof(parents) / sizeof(parents[0])) {
			if(level != 0)
				parents[level] = new QListViewItem(parents[level - 1],
															  (grpDisplayMode->selectedId() == 0) ?
															  device.getDesc() : device.getName());
			else
				parents[0] = new QListViewItem(lstDevices,
														 (grpDisplayMode->selectedId() == 0) ?
														 device.getDesc() : device.getName());
			parents[level]->setOpen(true);
		}
	}

	return(devinfo_foreach_device_child(dev, wrapper, ((char *) arg + 1)));
}


void  modDevInfo::readDevices() {
	devinfo_dev  *rootdev;

	if(devinfo_init() == 0 && (rootdev = devinfo_handle_to_device(DEVINFO_ROOT_DEVICE)) != NULL) {
		lstDevices->clear();
		devinfo_foreach_device_child(rootdev, wrapper, NULL);
	} else
		Dialogs::warnDlg("Unable to get device tree.");
}


void  modDevInfo::initModule() {
	setObject(this);
	readDevices();
}


void modDevInfo::init() {
	/* Initialize Graphics */
	DBSDIconLoader *iloader = DBSDGlobal::getIconLoader();
	btnRefresh->setIconSet(iloader->loadIcon("reload", DBSDIconLoader::Button));
}
