/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *         (C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#ifndef __TERMINAL_H
#define __TERMINAL_H

#include <qlabel.h>

class UnixProcess;

/**
  * This widget uses an xterm to display stdout
  * and stderr of a program and input characters.
  *
  */
class  Terminal : public QLabel {
	Q_OBJECT

public:
	Terminal(QWidget *parent = 0, const char *name = 0);
	virtual ~Terminal();

	int start();
	bool setProcess(const UnixProcess &);
	bool setContentGeometry(int cols, int rows);
	
	int exitStatus();
	bool isRunning();

public slots:
	virtual bool tryTerminate();

protected slots:
	virtual void checkIOAvailable();
	virtual void termProcessExited();

signals:
	void exited();

protected:
	void setErrorText(const QString &, const QString & = "");
	void cleanUp();

	virtual void closeEvent(QCloseEvent *c);
	virtual void mouseDoubleClickEvent(QMouseEvent *m);

private:
	QString	errorDetails;

	int           cols, rows;
	UnixProcess  *termProcess;

	int			  exitFIFO;
	QCString		 *exitFIFOPath;
	QTimer		 *ioTimer;

	int			  exitCode;
};

#endif /* __TERMINAL_H */
