/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *			(C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include "accesspoint.h"

#include <qstring.h>

/** Initializes the access point with a wi_apinfo struct.
  * This creates a deep copy of the given struct so you
  * can safely delete it's wi_req struct afterwards.
  */
AccessPoint::AccessPoint(const  struct  wi_apinfo&  apinfo) {
	this->apinfo = apinfo;
}



/** @return The station's SSID. */
QString  AccessPoint::getSSID()  const {
	return  QString::fromAscii(apinfo.name,  apinfo.namelen);
}



/** @returns The station's MAC address. */
QString  AccessPoint::getBSSID()  const {
	char  bssid[18];

	snprintf(bssid,  sizeof(bssid),  "%02X:%02X:%02X:%02X:%02X:%02X",
				apinfo.bssid[0] & 0xFF,
				apinfo.bssid[1] & 0xFF,
				apinfo.bssid[2] & 0xFF,
				apinfo.bssid[3] & 0xFF,
				apinfo.bssid[4] & 0xFF,
				apinfo.bssid[5] & 0xFF);

	return  bssid;
}



/** @return Or'ed values from the CapInfo enum */
int  AccessPoint::getCapInfo()  const {
	int  capinfo = None;

	if(apinfo.capinfo & IEEE80211_CAPINFO_ESS)
		capinfo |= ESS;

	if(apinfo.capinfo & IEEE80211_CAPINFO_PRIVACY)
		capinfo |= WEP;

	return  capinfo;
}



/** @return The data rate in Mbps or 0 if it
  *			is not 1, 2, 5.5 or 11 Mbps.
  */
double  AccessPoint::getRate()  const {
	double  rate;

	switch(apinfo.rate) {
		case WI_APRATE_1:
		rate = 1;
		break;

		case WI_APRATE_2:
		rate = 2;
		break;

		case WI_APRATE_5:
		rate = 5.5;
		break;

		case WI_APRATE_11:
		rate = 11;
		break;

		default:
		rate = 0;
		break;
	}

	return  rate;
}
