/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *			(C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include "portsupdateengine.h"

#include <qdir.h>

#include <unixprocess.h>
#include <dbsdsettings.h>

#define	MAKE_CMD				"/usr/bin/make"
#define	PORTS_DIR			"/usr/ports"
#define	DEFAULT_SUPFILE	"/usr/share/examples/cvsup/ports-supfile"


PortsUpdateEngine::PortsUpdateEngine() {
	updatePorts = true;
	indexMethod = FetchIndex;
}


/** Loads the cvsup server from the "packages" settings of
  * the DesktopBSD configuration using DBSDSettings.
  */
void  PortsUpdateEngine::readSettings() {
	DBSDSettings  s;

	cvsupServer = s.readEntry("/packages/cvsup_server", "");
	supFile = s.readEntry("/packages/supfile", DEFAULT_SUPFILE);
}


/** Returns a QProcess that acts on the ports tree
  * and the INDEX-5 file as configured before.
  *
  * Returns NULL if it is specified that neither
  * the ports tree nor the INDEX-5 file should be
  * updated (and therefore no actions would be done).
  *
  * The returned QProcess must be deleted after use.
  */
UnixProcess * PortsUpdateEngine::getProcess() {
	if(!updatePorts  &&  indexMethod == None)
		return  NULL;

	UnixProcess  *process = new UnixProcess(QString(MAKE_CMD));
	process->setWorkingDirectory(QDir(PORTS_DIR));

	if(updatePorts) {
		if(!supFile.isEmpty())
			process->addArgument("PORTSSUPFILE=" + supFile);

		process->addArgument("-DSUP_UPDATE");

		if(!cvsupServer.isEmpty())
			process->addArgument("SUPHOST=" + cvsupServer);

		/* Prefer csup over cvsup if available. */
		QString	sup = "/usr/local/bin/cvsup",
					localcsup = "/usr/local/bin/csup",
					usrcsup = "/usr/bin/csup";
		if(QFileInfo(localcsup).isExecutable())
			sup = localcsup;
		else if(QFileInfo(usrcsup).isExecutable())
			sup = usrcsup;

		process->addArgument("SUP=" + sup);

		process->addArgument("update");
	}


	if(indexMethod == FetchIndex)
		process->addArgument("fetchindex");
	else if(indexMethod == RebuildIndex)
		process->addArgument("index");

	return  process;
}
