/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *         (C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#ifndef __PORTSUPDATEENGINE_H
#define __PORTSUPDATEENGINE_H

#include <qstring.h>

class UnixProcess;

/**
  * @brief Uses cvsup to update the ports tree.
  *
  * This class creates a QProcess that updates
  * the ports tree and/or the INDEX-5 file (in
  * this order).
  *
  * The default is to update the ports tree and
  * fetch a new INDEX-5 file afterwards.
  *
  * Comments like [index] show the
  * corresponding make targets in /usr/ports.
  */
class PortsUpdateEngine {
public:
	enum IndexUpdateMethod {
	    None,
	    FetchIndex,	/**< [fetchindex] */
	    RebuildIndex	/**< [index     ] */
	};

	PortsUpdateEngine();

	UnixProcess * getProcess();

	void  readSettings();

	/** Specifies if the ports tree should be updated [update] */
	void	setUpdatePorts(bool b) { updatePorts = b;	}

	/** Specifies how the index file should be updated.
	  *
	  * @see IndexUpdateMethod
	  */
	void	setUpdateIndex(IndexUpdateMethod  method) { indexMethod = method; }

private:
	bool					updatePorts;
	QString				cvsupServer;
	QString				supFile;
	IndexUpdateMethod	indexMethod;
};

#endif /* __PORTSUPDATEENGINE_H */
