/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *			(C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#include "rcconf.h"

#include <qstring.h>

#include <executor.h>

QString  RCConf::getVar(const QString &  varName) {
	static const  QString  cmd = "sed -n 's/%1=\"\\(.*\\)\"/\\1/p' /etc/rc.conf";

	return  Executor::strFromCmd(cmd.arg(varName));
}


bool  RCConf::unsetVar(const QString &  varName) {
	static const  QString cmd =	"[ -w /etc/rc.conf ] && "
											"sed '/^\\(%1=\".*\"\\)*$/d' /etc/rc.conf > /tmp/dbsd-rcconf.$$ &&"
											"mv -f /tmp/dbsd-rcconf.$$ /etc/rc.conf";

	return  Executor::exec(cmd.arg(varName)) == Executor::NoError;
}

/** This sets an /etc/rc.conf variable to a specified value. */
bool RCConf::setVar(const QString& name, const QString& value) {
	if(!unsetVar(name))
		return false;

	FILE *f = fopen("/etc/rc.conf", "a");
	if(f == NULL)
		return false;

	bool retVal = fprintf(f, "\n%s=\"%s\"\n", name.latin1(), value.latin1()) > 0;

	fclose(f);
	return retVal;
}
